"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.RushHttpBuildCachePlugin = void 0;
const node_core_library_1 = require("@rushstack/node-core-library");
const HttpBuildCacheProviderModule = node_core_library_1.Import.lazy('./HttpBuildCacheProvider', require);
const PLUGIN_NAME = 'HttpBuildCachePlugin';
/**
 * @public
 */
class RushHttpBuildCachePlugin {
    constructor() {
        this.pluginName = PLUGIN_NAME;
    }
    apply(rushSession, rushConfig) {
        rushSession.hooks.initialize.tap(this.pluginName, () => {
            rushSession.registerCloudBuildCacheProviderFactory('http', (buildCacheConfig) => {
                const config = buildCacheConfig.httpConfiguration;
                const { url, uploadMethod, headers, tokenHandler, cacheKeyPrefix, isCacheWriteAllowed } = config;
                const options = {
                    pluginName: this.pluginName,
                    rushProjectRoot: rushConfig.rushJsonFolder,
                    url: url,
                    uploadMethod: uploadMethod,
                    headers: headers,
                    tokenHandler: tokenHandler,
                    cacheKeyPrefix: cacheKeyPrefix,
                    isCacheWriteAllowed: !!isCacheWriteAllowed
                };
                return new HttpBuildCacheProviderModule.HttpBuildCacheProvider(options, rushSession);
            });
        });
    }
}
exports.RushHttpBuildCachePlugin = RushHttpBuildCachePlugin;
//# sourceMappingURL=RushHttpBuildCachePlugin.js.map